"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryParam = void 0;
const QueryParameterExtractor_1 = require("../../../parameters/QueryParameterExtractor");
const DecoratorRegistry_1 = require("../../../reflection/DecoratorRegistry");
/**
 * Decorator which injects a query parameter value as an endpoint parameter value.
 *
 * Value passed to the method will be a string.
 *
 * @param paramName The name of the query parameter to inject.
 */
function queryParam(paramName, apiParamInfo) {
    return (classDefinition, methodName, paramIndex) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        endpoint.parameterExtractors[paramIndex] = new QueryParameterExtractor_1.QueryParameterExtractor(paramName, apiParamInfo);
    };
}
exports.queryParam = queryParam;
//# sourceMappingURL=queryParam.js.map